@@ -66,6 +66,7 @@ device_filter = click.option(
     "-d",
     "--device",
     default=None,
+    multiple=True,
     help="filter devices (supports pattern matching *,?,[])",
 )
 
@@ -73,6 +74,7 @@ class_filter = click.option(
     "--class",
     "class_",
     default=None,
+    multiple=True,
     help="filter devices of classes (supports pattern matching *,?,[])",
 )
 
@@ -80,13 +82,16 @@ server_filter = click.option(
     "-s",
     "--server",
     default=None,
+    multiple=True,
     help="filter servers (supports pattern matching *,?,[])",
 )
 
 starter_filter = click.option(
     "--starter",
     default=None,
-    help="filter starters (supports pattern matching *,?,[])",
+    multiple=True,
+    help="filter starters (supports pattern matching *,?,[]) " \
+    "(multiple values are ORed together)",
 )
 
 host_filter = click.option(
@@ -148,12 +153,14 @@ server_type_filter = click.option(
     "-t",
     "--server-type",
     default=None,
+    multiple=True,
     help="filter server type (supports pattern matching *,?,[])",
 )
 
 server_instance_filter = click.option(
     "--server-instance",
     default=None,
+    multiple=True,
     help="filter server instances (supports pattern matching *,?,[])",
 )
 
@@ -162,6 +169,7 @@ attr_filter = click.option(
     "--attribute",
     default=None,
     prompt=True,
+    multiple=True,
     help="attribute name (supports pattern matching *,?,[])",
 )
 
@@ -1262,7 +1270,7 @@ def starter_tree(starter, server, server_type, server_instance, all):
 
     tree = treelib.Tree()
     db_node = tree.create_node(db_name)
-    starters = list(tangoctl.iter_starters(starter=starter, db=db))
+    starters = list(tangoctl.iter_starters(starter_name=starter, db=db))
     starters_servers = tangoctl.starters_servers(*starters)
     for starter in starters:
         level_servers = collections.defaultdict(list)
@@ -1301,6 +1309,58 @@ def starter_tree(starter, server, server_type, server_instance, all):
     click.echo(str(tree))
 
 
+def _starter_stop(
+    starter, server, server_type, server_instance, timeout, stop_timeout, dry_run
+):
+    if dry_run:
+        click.secho("Making a dry run!", bold=True, fg="red")
+    try:
+        tangoctl.starter_stop_servers(
+            starter_name=starter,
+            server_name=server,
+            server_type=server_type,
+            server_instance=server_instance,
+            timeout=timeout,
+            stop_timeout=stop_timeout,
+            dry_run=dry_run,
+        )
+    except gevent.Timeout:
+        click.secho("Operation timeout ({} s)".format(timeout), fg="yellow")
+
+
+def _starter_start(starter, server, server_type, server_instance, timeout, dry_run):
+    if dry_run:
+        click.secho("Making a dry run!", bold=True, fg="red")
+    try:
+        tangoctl.starter_start_servers(
+            starter_name=starter,
+            server_name=server,
+            server_type=server_type,
+            server_instance=server_instance,
+            timeout=timeout,
+            dry_run=dry_run,
+        )
+    except gevent.Timeout:
+        click.secho("Operation timeout ({} s)".format(timeout), fg="yellow")
+
+
+def _starter_restart(starter, server, server_type, server_instance, timeout, dry_run):
+    # TODO: if no filter provided ask if really want to do it
+    if dry_run:
+        click.secho("Making a dry run!", bold=True, fg="red")
+    try:
+        tangoctl.starter_restart_servers(
+            starter_name=starter,
+            server_name=server,
+            server_type=server_type,
+            server_instance=server_instance,
+            timeout=timeout,
+            dry_run=dry_run,
+        )
+    except gevent.Timeout:
+        click.secho("Operation timeout ({} s)".format(timeout), fg="yellow")
+
+
 @starter_group.command("stop")
 @starter_filter
 @server_filter
@@ -1323,20 +1383,9 @@ def starter_stop(
     (level-1) servers are stopped only when all higher level servers
     have been stopped.
     """
-    if dry_run:
-        click.secho("Making a dry run!", bold=True, fg="red")
-    try:
-        tangoctl.starter_stop_servers(
-            starter_name=starter,
-            server_name=server,
-            server_type=server_type,
-            server_instance=server_instance,
-            timeout=timeout,
-            stop_timeout=stop_timeout,
-            dry_run=dry_run,
-        )
-    except gevent.Timeout:
-        click.secho("Operation timeout ({} s)".format(timeout), fg="yellow")
+    return _starter_stop(
+        starter, server, server_type, server_instance, timeout, stop_timeout, dry_run
+    )
 
 
 @starter_group.command("start")
@@ -1358,19 +1407,7 @@ def starter_start(starter, server, server_type, server_instance, timeout, dry_ru
     (level+1) servers are started only when all lower level servers
     have been started.
     """
-    if dry_run:
-        click.secho("Making a dry run!", bold=True, fg="red")
-    try:
-        tangoctl.starter_start_servers(
-            starter_name=starter,
-            server_name=server,
-            server_type=server_type,
-            server_instance=server_instance,
-            timeout=timeout,
-            dry_run=dry_run,
-        )
-    except gevent.Timeout:
-        click.secho("Operation timeout ({} s)".format(timeout), fg="yellow")
+    return _starter_start(starter, server, server_type, server_instance, timeout, dry_run)
 
 
 @starter_group.command("restart")
@@ -1408,19 +1445,7 @@ def starter_restart(starter, server, server_type, server_instance, timeout, dry_
         (level+1) servers are started only when all lower level servers
         have been started.
     """
-    if dry_run:
-        click.secho("Making a dry run!", bold=True, fg="red")
-    try:
-        tangoctl.starter_restart_servers(
-            starter_name=starter,
-            server_name=server,
-            server_type=server_type,
-            server_instance=server_instance,
-            timeout=timeout,
-            dry_run=dry_run,
-        )
-    except gevent.Timeout:
-        click.secho("Operation timeout ({} s)".format(timeout), fg="yellow")
+    return _starter_restart(starter, server, server_type, server_instance, timeout, dry_run)
 
 
 if __name__ == "__main__":
