@@ -310,6 +310,18 @@ def access_str(access):
     return "?"
 
 
+def fnmatch_any(name, patterns, case_insensitive=False):
+    """helper that returns True if name matches any in the list of patterns"""
+    if not patterns:
+        return True
+    if isinstance(patterns, str):
+        patterns = (patterns,)
+    if case_insensitive:
+        name = name.lower()
+        patterns = [p.lower() for p in patterns]
+    return any(fnmatch.fnmatch(name, pattern) for pattern in patterns)
+
+
 # ----- API -----
 
 
@@ -323,23 +335,16 @@ def iter_devices(
     devices = (devs[dname] for dname in sorted(devs))
     if exclude_dserver:
         devices = (d for d in devices if d.klass != "DServer")
-    if device:
-        device = device.lower()
-        devices = (
-            d
-            for d in devices
-            if fnmatch.fnmatch(d.name.lower(), device)
-            or (d.alias and fnmatch.fnmatch(d.alias.lower(), device))
-        )
-    if klass:
-        devices = (d for d in devices if fnmatch.fnmatch(d.klass, klass))
-    if server:
-        devices = (d for d in devices if fnmatch.fnmatch(d.server, server))
-    if host:
-        host = host.lower()
-        devices = (
-            d for d in devices if fnmatch.fnmatch(servers[d.server].host.lower(), host)
-        )
+    devices = (
+        d
+        for d in devices
+        if fnmatch_any(d.name, device, case_insensitive=True)
+        or (d.alias and fnmatch_any(d.alias, device, case_insensitive=True))
+    )
+    devices = (d for d in devices if fnmatch_any(d.klass, klass))
+    devices = (d for d in devices if fnmatch_any(d.server, server))
+    devices = (d for d in devices if fnmatch_any(servers[d.server], host,
+                                                 case_insensitive=True))
     return devices
 
 
@@ -347,12 +352,9 @@ def iter_servers(server=None, server_type=None, server_instance=None, db=None):
     db_info = get_db_info(db=db)
     servers = db_info.servers
     servs = (servers[sname] for sname in sorted(servers))
-    if server:
-        servs = (s for s in servs if fnmatch.fnmatch(s.name, server))
-    if server_type:
-        servs = (s for s in servs if fnmatch.fnmatch(s.type, server_type))
-    if server_instance:
-        servs = (s for s in servs if fnmatch.fnmatch(s.instance, server_instance))
+    servs = (s for s in servs if fnmatch_any(s.name, server))
+    servs = (s for s in servs if fnmatch_any(s.type, server_type))
+    servs = (s for s in servs if fnmatch_any(s.instance, server_instance))
     return servs
 
 
@@ -367,11 +369,7 @@ def server_info(name, db=None):
 def expr_to_iservers(expr, db=None):
     db = get_db(db)
     servers = db.get_server_list()
-    if expr is None:
-        return servers
-    if not isinstance(expr, (list, tuple)):
-        expr = (expr,)
-    f = lambda server: any(fnmatch.fnmatch(server, pat) for pat in expr)
+    f = lambda server: fnmatch_any(server, expr)
     return filter(f, servers)
 
 
@@ -434,10 +432,7 @@ def expr_to_idevices(expr, exclude_dserver=True, db=None):
     devices = (devs[dname] for dname in sorted(devs))
     if exclude_dserver:
         devices = (d for d in devices if d.klass != "DServer")
-    if expr is None:
-        return devices
-    expr_lower = [pat.lower() for pat in expr]
-    f = lambda dev: any(fnmatch.fnmatch(dev.name.lower(), pat) for pat in expr_lower)
+    f = lambda dev: fnmatch_any(dev.name.lower(), expr, case_insensitive=True)
     return filter(f, devices)
 
 
@@ -503,12 +498,7 @@ def _attr_to_dict(config=None, value=None):
 
 
 def expr_to_iattrs(expr, attribute_names):
-    if expr is None:
-        return attribute_names
-    if not isinstance(expr, (list, tuple)):
-        expr = (expr,)
-    expr_lower = [pat.lower() for pat in expr]
-    f = lambda name: any(fnmatch.fnmatch(name.lower(), pat) for pat in expr_lower)
+    f = lambda name: fnmatch_any(name, expr, case_insensitive=True)
     return filter(f, attribute_names)
 
 
@@ -549,26 +539,16 @@ def device_attribute_info(name, attribute):
 def device_attributes(dev_name, attribute=None):
     device = Device(dev_name)
     attrs = device.attribute_list_query_ex()
-    if attribute:
-        attribute = attribute.lower()
-
-        def filt(attr):
-            fnmatch.fnmatch(attr.name.lower(), attribute)
-
-        attrs = filter(filt, attrs)
+    f = lambda attr: fnmatch_any(attr.name, attribute, case_insensitive=True)
+    attrs = filter(f, attrs)
     return sorted(attrs, key=lambda a: a.name)
 
 
 def device_commands(dev_name, command=None):
     device = Device(dev_name)
     cmds = device.command_list_query()
-    if command:
-        command = command.lower()
-
-        def filt(cmd):
-            fnmatch.fnmatch(cmd.cmd_name.lower(), command)
-
-        attrs = filter(filt, cmds)
+    f = lambda cmd: fnmatch_any(cmd.cmd_name, command, case_insensitive=True)
+    attrs = filter(f, cmds)
     return sorted(cmds, key=lambda a: a.cmd_name)
 
 
@@ -578,12 +558,7 @@ def device_command_info(name, command):
 
 
 def expr_to_iprops(expr, prop_names):
-    if expr is None:
-        return prop_names
-    if not isinstance(expr, (list, tuple)):
-        expr = (expr,)
-    expr_lower = [pat.lower() for pat in expr]
-    f = lambda name: any(fnmatch.fnmatch(name.lower(), pat) for pat in expr_lower)
+    f = lambda name: fnmatch_any(name, expr)
     return filter(f, prop_names)
 
 
@@ -697,7 +672,7 @@ class Starter:
                 "skipped killing %r (%s)", name, human_starter_server_state(state)
             )
             return True
-        self._log.info("killing %r", name)
+        self._log.info("killing %r...", name)
         if not dry_run:
             try:
                 self.starter_device.HardKillServer(name)
@@ -737,7 +712,7 @@ class Starter:
                 level,
             )
             return True
-        self._log.info("stopping %r (level %d)", name, level)
+        self._log.info("stopping %r (level %d)...", name, level)
         if not dry_run:
             try:
                 self.starter_device.DevStop(name)
@@ -812,24 +787,18 @@ def starters(db=None):
     return STARTERS[db]
 
 
-def iter_starters(starter=None, db=None):
+def iter_starters(starter_name=None, db=None):
     result = iter(starters(db=db).values())
-    if starter:
-        result = (s for s in result if fnmatch.fnmatch(s.name, starter))
+    result = (s for s in result if fnmatch_any(s.name, starter_name))
     return result
 
 
 def iter_starter_servers(
     servers, server_name=None, server_type=None, server_instance=None
 ):
-    if server_name:
-        servers = (s for s in servers if fnmatch.fnmatch(s["info"].name, server_name))
-    if server_type:
-        servers = (s for s in servers if fnmatch.fnmatch(s["info"].type, server_type))
-    if server_instance:
-        servers = (
-            s for s in servers if fnmatch.fnmatch(s["info"].instance, server_instance)
-        )
+    servers = (s for s in servers if fnmatch_any(s["info"].name, server_name))
+    servers = (s for s in servers if fnmatch_any(s["info"].type, server_type))
+    servers = (s for s in servers if fnmatch_any(s["info"].instance, server_instance))
     return servers
 
 
